@@ -6,7 +6,7 @@ import sqlalchemy
 from gino import Gino
 from sanic import Blueprint, Sanic, response, router
 from sanic_jwt import Initialize
-
+import sanic_routing
 from gino_admin import config
 from gino_admin.auth import authenticate
 from gino_admin.history import add_history_model
@@ -140,7 +140,7 @@ def add_admin_panel(app: Sanic, db: Gino, db_models: List, **config_settings):
     try:
         Initialize(app, authenticate=authenticate, url_prefix=f"{cfg.route}/api/auth")
         Initialize(rest.api, app=app, authenticate=authenticate, auth_mode=True)
-    except router.RouteExists:
+    except sanic_routing.exceptions.RouteExists:
         pass
     # to avoid re-write app Jinja2
     if getattr(app, "extensions", None):
